@@ -7,7 +7,7 @@ with 'Catalyst::View::EmbeddedPerl::PerRequest::ValiantRole';
 
 __PACKAGE__->meta->make_immutable;
 __PACKAGE__->config(
-  prepend => 'use v5.40', 
+  #prepend => 'use v5.40', 
   content_type=>'text/html; charset=UTF-8'
 );
 
