@@ -9,7 +9,8 @@ has 'name' => (is => 'ro', isa => 'Str');
 __PACKAGE__->meta->make_immutable;
 
 __DATA__
-%= form_for('person', sub ($self, $fb, $model) {
+%= form_for('person', sub {
+    % my ($self, $fb, $model) = @_;\
     %= $fb->input('name');
     %= $fb->input('age');
 % });\
